@@ -25,12 +25,14 @@ OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
 from __future__ import unicode_literals
+import platform
 import warnings
 
 try:
     from .StringMatcher import StringMatcher as SequenceMatcher
 except ImportError:
-    warnings.warn('Using slow pure-python SequenceMatcher. Install python-Levenshtein to remove this warning')
+    if platform.python_implementation() != "PyPy":
+        warnings.warn('Using slow pure-python SequenceMatcher. Install python-Levenshtein to remove this warning')
     from difflib import SequenceMatcher
 
 from . import utils
@@ -49,7 +51,6 @@ def ratio(s1, s2):
     return utils.intr(100 * m.ratio())
 
 
-# todo: skip duplicate indexes for a little more speed
 @utils.check_for_none
 @utils.check_empty_string
 def partial_ratio(s1, s2):
@@ -86,7 +87,7 @@ def partial_ratio(s1, s2):
         else:
             scores.append(r)
 
-    return int(100 * max(scores))
+    return utils.intr(100 * max(scores))
 
 
 ##############################
@@ -131,6 +132,7 @@ def partial_token_sort_ratio(s1, s2, force_ascii=True):
     """
     return _token_sort(s1, s2, partial=True, force_ascii=force_ascii)
 
+
 @utils.check_for_none
 def _token_set(s1, s2, partial=True, force_ascii=True):
     """Find all alphanumeric tokens in each string...
@@ -189,8 +191,6 @@ def partial_token_set_ratio(s1, s2, force_ascii=True):
     return _token_set(s1, s2, partial=True, force_ascii=force_ascii)
 
 
-# TODO: numerics
-
 ###################
 # Combination API #
 ###################
@@ -250,12 +250,12 @@ def WRatio(s1, s2, force_ascii=True):
         ptser = partial_token_set_ratio(p1, p2, force_ascii=force_ascii) \
             * unbase_scale * partial_scale
 
-        return int(max(base, partial, ptsor, ptser))
+        return utils.intr(max(base, partial, ptsor, ptser))
     else:
         tsor = token_sort_ratio(p1, p2, force_ascii=force_ascii) * unbase_scale
         tser = token_set_ratio(p1, p2, force_ascii=force_ascii) * unbase_scale
 
-        return int(max(base, tsor, tser))
+        return utils.intr(max(base, tsor, tser))
 
 
 def UWRatio(s1, s2):
