@@ -3,6 +3,7 @@ from __future__ import unicode_literals
 import unittest
 import re
 import sys
+import pep8
 
 from fuzzywuzzy import fuzz
 from fuzzywuzzy import process
@@ -263,26 +264,6 @@ class RatioTest(unittest.TestCase):
         score = fuzz._token_sort(s1, s2, force_ascii=False)
         self.assertLess(score, 100)
 
-    # test processing methods
-    def testGetBestChoice1(self):
-        query = "new york mets at atlanta braves"
-        best = process.extractOne(query, self.baseball_strings)
-        self.assertEqual(best[0], "braves vs mets")
-
-    def testGetBestChoice2(self):
-        query = "philadelphia phillies at atlanta braves"
-        best = process.extractOne(query, self.baseball_strings)
-        self.assertEqual(best[0], self.baseball_strings[2])
-
-    def testGetBestChoice3(self):
-        query = "atlanta braves at philadelphia phillies"
-        best = process.extractOne(query, self.baseball_strings)
-        self.assertEqual(best[0], self.baseball_strings[2])
-
-    def testGetBestChoice4(self):
-        query = "chicago cubs vs new york mets"
-        best = process.extractOne(query, self.baseball_strings)
-        self.assertEqual(best[0], self.baseball_strings[0])
 
 class ValidatorTest(unittest.TestCase):
     def setUp(self):
@@ -296,13 +277,11 @@ class ValidatorTest(unittest.TestCase):
         ]
         decorated_func = utils.check_for_none(self.testFunc)
         for i in invalid_input:
-            self.assertRaises(TypeError, decorated_func, *i)
+            self.assertEqual(decorated_func(*i), 0)
 
-        try:
-            valid_input = ['Some', 'Some']
-            decorated_func(*valid_input)
-        except ValueError as e:
-            self.fail('check_for_none matched non-None input', valid_input, e)
+        valid_input = ('Some', 'Some')
+        actual = decorated_func(*valid_input)
+        self.assertNotEqual(actual, 0)
 
     def testCheckEmptyString(self):
         invalid_input = [
@@ -346,6 +325,26 @@ class ProcessTest(unittest.TestCase):
             "braves vs mets",
         ]
 
+    def testGetBestChoice1(self):
+        query = "new york mets at atlanta braves"
+        best = process.extractOne(query, self.baseball_strings)
+        self.assertEqual(best[0], "braves vs mets")
+
+    def testGetBestChoice2(self):
+        query = "philadelphia phillies at atlanta braves"
+        best = process.extractOne(query, self.baseball_strings)
+        self.assertEqual(best[0], self.baseball_strings[2])
+
+    def testGetBestChoice3(self):
+        query = "atlanta braves at philadelphia phillies"
+        best = process.extractOne(query, self.baseball_strings)
+        self.assertEqual(best[0], self.baseball_strings[2])
+
+    def testGetBestChoice4(self):
+        query = "chicago cubs vs new york mets"
+        best = process.extractOne(query, self.baseball_strings)
+        self.assertEqual(best[0], self.baseball_strings[0])
+
     def testWithProcessor(self):
         events = [
             ["chicago cubs vs new york mets", "CitiField", "2011-05-11", "8pm"],
@@ -353,9 +352,8 @@ class ProcessTest(unittest.TestCase):
             ["atlanta braves vs pittsburgh pirates", "PNC Park", "2011-05-11", "8pm"],
         ]
         query = "new york mets vs chicago cubs"
-        processor = lambda event: event[0]
 
-        best = process.extractOne(query, events, processor=processor)
+        best = process.extractOne(query, events, processor=lambda event: event[0])
         self.assertEqual(best[0], events[0])
 
     def testWithScorer(self):
@@ -501,5 +499,13 @@ class ProcessTest(unittest.TestCase):
         self.assertEqual(result, deduped_list)
 
 
+class TestCodeFormat(unittest.TestCase):
+    def test_pep8_conformance(self):
+        pep8style = pep8.StyleGuide(quiet=True)
+        pep8style.options.ignore = pep8style.options.ignore + tuple(['E501'])
+        pep8style.input_dir('fuzzywuzzy')
+        result = pep8style.check_files()
+        self.assertEqual(result.total_errors, 0, "PEP8 POLICE - WOOOOOWOOOOOOOOOO")
+
 if __name__ == '__main__':
     unittest.main()         # run all tests
